function interp = AD9162Setup(ads7, interpIn, numLanesIn)
%
% *** Do not edit this file.                    ***
% *** Contains evalboard specific configuration ***
%
% This is the setup function for the AD9162.
% The JESD204 lanes and link parameters for
% the dac modes are setup.
%
% ads7       - Ads7 IHardwareDevice
% interpIn   - Interpolation value
% numLanesIn - Number of lanes (only used when interpIn is > 1)
interp = interpIn;
numLanes = numLanesIn;
disp(['Setting up interp: ', num2str(interp), ' numLanes: ', num2str(numLanes)]);
disp(ads7.FriendlyName)

% Get reference to JESD204Core
jesd204Core = ads7.Jesd204Core;

% Single link
jesd204Core.Tx.FramerCount = 1;

% Set the FMC LA signal mapping
jesd204Core.Tx.SetSignalLAPort('SYNC0', 1);
jesd204Core.Tx.SetSignalLAPort('SYNC1', 2);  % Where to put this?
jesd204Core.Tx.SetSignalLAPort('SYSREF', 0);

% Enable sysref sourcing by ADS7
jesd204Core.Tx.EnableSysRefSourcing = true;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lane configuration for AD9162-FMC-EBZ
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
jesd204Core.Tx.Lanes(0+1).LogicalLane = 0;
jesd204Core.Tx.Lanes(1+1).LogicalLane = 1;
jesd204Core.Tx.Lanes(2+1).LogicalLane = 2;
jesd204Core.Tx.Lanes(3+1).LogicalLane = 3;
jesd204Core.Tx.Lanes(4+1).LogicalLane = 5;
jesd204Core.Tx.Lanes(5+1).LogicalLane = 7;
jesd204Core.Tx.Lanes(6+1).LogicalLane = 6;
jesd204Core.Tx.Lanes(7+1).LogicalLane = 4;

jesd204Core.Tx.Lanes(0+1).InvertPolarity = false;
jesd204Core.Tx.Lanes(1+1).InvertPolarity = false;
jesd204Core.Tx.Lanes(2+1).InvertPolarity = false;
jesd204Core.Tx.Lanes(3+1).InvertPolarity = false;
jesd204Core.Tx.Lanes(4+1).InvertPolarity = true;
jesd204Core.Tx.Lanes(5+1).InvertPolarity = true;
jesd204Core.Tx.Lanes(6+1).InvertPolarity = true;
jesd204Core.Tx.Lanes(7+1).InvertPolarity = true;

% Index of JESD params in table
M=1;L=2;S=3;F=4;K=5;HD=6;N=7;Np=8;Scrm=9;Sub=10;

if (interp > 1)
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % AD9162 DAC JESD204 Paramters for interp > 1
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    cM = containers.Map('KeyType', 'int32', 'ValueType', 'any');

    %#Lanes   M  L  S  F  K  HD      N   Np  Scrm  Sub
    cM(8)  = [2  8  2  1  32 true    16  16  true  0  ];
    cM(6)  = [2  6  3  2  32 true    16  16  true  0  ];
    cM(4)  = [2  4  1  1  32 true    16  16  true  0  ];
    cM(3)  = [2  3  3  4  32 true    16  16  true  0  ];
    cM(2)  = [2  2  1  2  32 true    16  16  true  0  ];
    cM(1)  = [2  1  1  4  32 true    16  16  true  0  ];
    
    modeParams = cM(numLanes);
else
                 %M  L  S  F  K  HD      N   Np  Scrm  Sub
    modeParams = [1  8  4  1  32 true    16  16  true  1  ];
end

% JESD204 params
jesd204Core.Tx.M =  modeParams(M);
jesd204Core.Tx.L = modeParams(L);
jesd204Core.Tx.F = modeParams(F);
jesd204Core.Tx.S = modeParams(S);
jesd204Core.Tx.K = modeParams(K);
jesd204Core.Tx.HD = modeParams(HD);
jesd204Core.Tx.N = modeParams(N);
jesd204Core.Tx.Np = modeParams(Np);
jesd204Core.Tx.Scrambling = modeParams(Scrm);

if (modeParams(Sub)==0)
    jesd204Core.Tx.Subclass = AnalogDevices.DPG.Interfaces.SubclassMode.Subclass0;
elseif (modeParams(Sub)==1)
    jesd204Core.Tx.Subclass = AnalogDevices.DPG.Interfaces.SubclassMode.Subclass1;
else
    jesd204Core.Tx.Subclass = AnalogDevices.DPG.Interfaces.SubclassMode.Subclass2;
end

% Select the Tx ref clock and intial PLL.
jesd204Core.Clocks.AutoPllSelect = true;
jesd204Core.Clocks.Configure(AnalogDevices.DPG.Interfaces.Jesd204XcvrType.Tx, AnalogDevices.DPG.Interfaces.Jesd204PllType.QPLL, 0);
end