function [ads7, isDownloadError] = GetAds7(downloadFpgaConfig)
%
% *** Do not edit this file.                    ***
% *** Contains ADS7 specific initialization      ***
%
% This function will find and create an ADS7
% hardware interface. See the definition for IHardwareDevice
% for methods and properties available.
% Wiki link: http://wiki.analog.com/resources/eval/dpg/programming_reference
%
% downloadFpgaConfig
%    true  - Force downloading FPGA config
%    false - Only download FPGA config if necessary

hpf = AnalogDevices.DPG.PluginFinder.HardwarePluginFinder;
hardwarePlugins = hpf.FindPluginsFiltered('*');
for i=1:hardwarePlugins.Length    
    disp(['Plugin: ', char(hardwarePlugins(i).FriendlyName)]);
    if(strcmp(char(hardwarePlugins(i).FriendlyName),'ADS7 Series Interface') == true)
        dpg_interface = hardwarePlugins(i);
    end
end

devices = dpg_interface.AttachedDevices;
ads7 = devices(1);

currentFpgaConfig = char(ads7.CurrentConfiguration);
disp(['currentFpgaConfig: ', currentFpgaConfig]);

% Determine if FPGA config already loaded
fpgaAlreadyLoaded = strcmp(currentFpgaConfig, 'JESD204B');

isDownloadError = false;
if (downloadFpgaConfig || fpgaAlreadyLoaded == false)    
    % Download ADS7-V1, ADS7-V2 or ADS8-V1 FPGA config.
    % Synchronous download. Will return when done loading.
    if (strcmp(char(ads7.FriendlyName), 'ADS7-V2'))
        disp('Downloading ADS7-V2 fpga config');
        isDownloadError = ads7.DownloadConfiguration('C:\Program Files (x86)\Analog Devices\DPG\FPGA Configurations\JESD204B.C.ADS7V2');
        if (isDownloadError)
            isDownloadError = ads7.DownloadConfiguration('C:\Program Files (x86)\Analog Devices\DPG\FPGA Configurations\JESD204B.B.ADS7V2');
        end
    elseif (strcmp(char(ads7.FriendlyName), 'ADS7-V1'))
        disp('Downloading ADS7-V1 fpga config');
        isDownloadError = ads7.DownloadConfiguration('C:\Program Files (x86)\Analog Devices\DPG\FPGA Configurations\JESD204B.C.ADS7V1');
        if (isDownloadError)
            isDownloadError = ads7.DownloadConfiguration('C:\Program Files (x86)\Analog Devices\DPG\FPGA Configurations\JESD204B.B.ADS7V1');
        end
    elseif (strcmp(char(ads7.FriendlyName), 'ADS8-V1'))
        disp('Downloading ADS8-V1 fpga config');
        isDownloadError = ads7.DownloadConfiguration('C:\Program Files (x86)\Analog Devices\DPG\FPGA Configurations\JESD204B.B.ADS8V1');
        if (isDownloadError)
            isDownloadError = ads7.DownloadConfiguration('C:\Program Files (x86)\Analog Devices\DPG\FPGA Configurations\JESD204B.A.ADS8V1');
        end
    end
    
    if (isDownloadError)
        disp('FPGA config download ERROR.');
    else
        disp('FPGA config was loaded OK.');
    end
end

end
